{% extends "base.html" %}
{% import 'includes/macros.html' as macros %}

{% block main_header %}
<meta name="description" content="{{meta.description}}" />
<meta name="author" content="{{meta.author}}" />
<link href="{{meta.URL}}" rel="canonical" />
<title>{{meta.title}}</title>
<meta content="{{meta.title}}" property="og:title" />
<meta content="{{meta.description}}" property="og:description" />
<meta content="{{meta.url}}" property="og:url" />
{% endblock main_header %}

{% block main_content %}
<!-- Header-->
<header class="bg-dark py-5" id="home">
    <div class="container px-5">
        <div class="row gx-5 align-items-center justify-content-center">
            <div class="col-lg-8 col-xl-7 col-xxl-6">
                <div class="my-5 text-center text-xl-start">
                    <h1 class="display-5 fw-bolder text-white mb-2">Oops! This page doen not exists.
                    </h1>
                    <p class="lead fw-normal text-white-50 mb-4"> You hit an invalid route and this page does not exist.
                        You can visit our home page or meetups page to get more information about our website.
                    </p>
                    <div class="d-grid gap-3 d-sm-flex justify-content-sm-center justify-content-xl-start">
                        <a class="btn btn-primary btn-lg px-4 me-sm-3" href="{{meta.URL}}/">Home</a>
                        <a class="btn btn-primary btn-lg px-4 me-sm-3"
                            href="{{meta.URL}}/{{meta.folders.meetups}}/">Meetups</a>
                    </div>
                </div>
            </div>
            <div class="col-xl-5 col-xxl-6 d-none d-xl-block text-center"><img class="img-fluid rounded-3 my-5"
                    src="{{meta.URL}}/static/assets/banner.png" alt="{{meta.name}} about us banner" /></div>
        </div>
    </div>
</header>
<section class="py-5 bg-light" id="meetups">
    <div class="container px-5 my-5">
        <div class="row gx-5 justify-content-left">
            <div class="col-lg-12">
                <div class="text-left">
                    <h2 class="fw-bolder  mb-4">Meetups</h2>
                    <p class="lead fw-normal text-muted mb-5">Here is the list of upcoming meetups organized by
                        {{meta.name}}.</p>
                </div>
            </div>
        </div>
        <div class="row gx-5">
            {% for meetup in meetups%}
                {{macros.meetup_card(meta, meetup)}}
            {% endfor%}
        </div>
        <div class="text-end mb-5 mb-xl-0">
            <a class="text-decoration-none" href="{{meta.URL}}/{{meta.folders.meetups}}/">
                Older Meetups
                <i class="bi bi-arrow-right"></i>
            </a>
        </div>
    </div>
</section>
{% endblock main_content %}