<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge">

    {% block main_header %}
    {% endblock main_header %}
    <meta content="{{meta.name}}" property="og:site_name" />
    <meta name="keywords" content="Python User Group, Bodensee, Python Stammtisch">
    <meta content="en_US" property="og:locale" />
    <meta content="website" property="og:type" />
    <meta name="apple-mobile-web-app-title" content="{{meta.name}}" />
    <meta name="application-name" content="{{meta.name}}" />
    <meta property="og:image" content="{{meta.url}}/static/assets/logo.png" />
    <meta content="282" property="og:image:width" />
    <meta content="104" property="og:image:height" />
    <meta content="image/png" property="og:image:type" />

    <link rel="icon" type="image/x-icon" href="{{meta.url}}/static/assets/favicon.png" />
    <link rel="shortcut icon" href="{{meta.url}}/static/assets/favicon.png" />
    <meta content="{{meta.url}}/favicon.ico" name="msapplication-TileImage">

    <meta name="generator" content="meetlify" />
    <meta name="language" content="english" />
    <meta name="format-detection" content="telephone=yes" />
    <meta name="HandheldFriendly" content="true" />
    <meta name="distribution" content="web" />
    <meta name="msapplication-TileColor" content="#2b5797" />
    <meta name="next-font-preconnect" />
    <meta name="theme-color" content="#ffffff" />
    <meta http-equiv="Content-Style-Type" content="text/css" />
    <meta http-equiv="Content-Script-Type" content="text/javascript" />
    <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
    <meta http-equiv="Content-Security-Policy" content="upgrade-insecure-requests">

    <meta name="robots" content="index, follow, max-image-preview:large, max-snippet:-1" />
    <meta name="bingbot" content="index, follow, max-image-preview:large, max-snippet:-1" />
    <meta name="googlebot" content="index, follow, max-image-preview:large, max-snippet:-1" />

    <!-- Favicon-->
    <link rel="icon" type="image/x-icon" href="{{meta.URL}}/static/assets/favicon.png" />
    <!-- Bootstrap icons-->
    <link href="{{meta.URL}}/static/css/bootstrap-icons.css" rel="stylesheet" />
    <!-- Core theme CSS (includes Bootstrap)-->
    <link href="{{meta.URL}}/static/css/styles.css" rel="stylesheet" />
    <link href="{{meta.URL}}/static/css/custom.css" rel="stylesheet" />
    <!-- Cookies Alert-->
    <link href="{{meta.URL}}/static/css/cookiealert.css" rel="stylesheet">
</head>

<body class="d-flex flex-column h-100">
    <main class="flex-shrink-0">
        <!-- Navigation-->
        <nav class="navbar navbar-expand-lg navbar-dark bg-dark">
            <div class="container px-5">
                <a class="navbar-brand" href="/">
                    <img src="{{meta.URL}}/static/assets/{{meta.logo}}" width="80" height="30"
                        class="d-inline-block align-top" alt="{{meta.name}} Logo"></a>
                <a class="navbar-brand" href="/">{{meta.name}}</a>
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse"
                    data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent"
                    aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon">
                    </span>
                </button>
                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                    <ul class="navbar-nav ms-auto mb-2 mb-lg-0">
                        {% for key,value in meta.menu.header.items()%}
                        {% if value.startswith('https://') %}
                        <li class="nav-item"><a class="nav-link" href="{{value}}/" target="_blank">{{key}}</a></li>
                        {% else %}
                        <li class="nav-item"><a class="nav-link" href="{{meta.URL}}/{{value}}/">{{key}}</a></li>
                        {% endif %}
                        {% endfor %}
                    </ul>
                </div>
            </div>
        </nav>
        {% block main_content %}
        {% endblock main_content %}
    </main>
    <!-- Footer-->
    <footer class="bg-dark py-4 mt-auto">
        <div class="container px-5 footer">
            <div class="row align-items-center justify-content-between flex-column flex-sm-row">
                <div class="col-auto">
                    <div class="m-0 text-white">{{meta.copyright}}</div>
                </div>
                <div class="col-auto footer">
                    {% for key,value in meta.menu.footer.items()%}
                    <a class="link-light" href="{{meta.URL}}/{{value}}/">{{key}}</a>

                    <span class="text-white mx-1">{{ "&middot;" if not loop.last else "" }}</span>
                    {% endfor %}
                </div>
            </div>
        </div>
    </footer>

    <div id="cb-cookie-banner" class="alert bg-dark text-white text-center mb-0" role="alert">
        We and our selected third parties use cookies 🍪 or similar technologies to ensure
        you get the best experience on our website as specified in the our <a class="text-white"
            href="{{meta.url}}/privacy/" target="_blank">Privacy Policy</a> and <a class="text-white"
            href="{{meta.url}}/terms/" target="_blank">Terms of
            Services</a>. If you continue to use this site we will
        assume that you are happy with it.
        <button type="button" class="btn btn-primary btn-sm ms-3" onclick="window.cb_hideCookieBanner()">
            I Agree
        </button>
    </div>

    <!-- Bootstrap core JS-->
    <script src="{{meta.URL}}/static/js/cookiealert.js"></script>
    <script src="{{meta.URL}}/static/js/bootstrap.bundle.min.js"></script>
    <!-- Core theme JS-->
    <script src="{{meta.URL}}/static/js/scripts.js"></script>
</body>

</html>